@@ -182,7 +182,7 @@ sub setValue {
 
 Sets the text of the entry
 
-Note: for setting both the text and blur value, see L<IWL::Entry::setValue()>
+Note: for setting both the text and blur value, see L<IWL::Entry::setValue|/setValue>
 
 Parameter: B<TEXT> - the text.
 
@@ -523,7 +523,7 @@ sub __setIcon {
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2006-2007  Viktor Kojouharov. All rights reserved.
+Copyright (c) 2006-2008  Viktor Kojouharov. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See perldoc perlartistic.
