@@ -90,15 +90,15 @@ sub packEnd {
 sub _realize {
     my $self = shift;
 
+    $self->appendChild(IWL::Container->new(class => 'iwl-clear'));
     $self->SUPER::_realize;
-    $self->appendAfter(IWL::Container->new(inline => 1, style => {clear => 'both'}));
 }
 
 1;
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2006-2007  Viktor Kojouharov. All rights reserved.
+Copyright (c) 2006-2008  Viktor Kojouharov. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See perldoc perlartistic.
