@@ -72,7 +72,7 @@ The parent for the current object. Null if it has no parent.
 
 sub new {
     my ($class, %args) = @_;
-    my $self  = bless {}, $class;
+    my $self  = bless {}, (ref $class || $class);
 
     $self->{childNodes} = [];
     $self->{parentNode} = undef;
@@ -101,8 +101,6 @@ sub new {
     $self->{environment} = ref $args{environment} eq 'IWL::Environment'
         ? $args{environment} : undef;
 
-    delete $args{environment};
-
     return $self;
 }
 
@@ -576,9 +574,9 @@ sub getContent {
 
     return '' if $self->bad;
     if (!$self->{_realized}) {
-        $self->{_realized} = 1;
         $self->_realize;
         $self->__addInitScripts;
+        $self->{_realized} = 1;
     }
 
     return '' if $self->bad;
@@ -672,9 +670,9 @@ sub getObject {
 
     return {} if $self->bad;
     if (!$self->{_realized}) {
-        $self->{_realized} = 1;
         $self->_realize;
         $self->__addInitScripts;
+        $self->{_realized} = 1;
     }
 
     return {} if $self->bad;
@@ -971,7 +969,7 @@ sub appendAfter {
     return $self;
 }
 
-=item B<requiredJs> [B<URLS>]
+=item B<requiredJs> (B<URLS>)
 
 Adds the list of urls (relative to JS_DIR, or absolute) as required by the object
 
@@ -991,19 +989,20 @@ sub requiredJs {
 		'scriptaculous_extensions.js');
 	}
 
-	my $src    = $url ;
-	$src       = $IWLConfig{JS_DIR} . '/' . $src
-	    unless $url =~ m{^(?:(?:https?|ftp|file)://|/)};
+        $url = $IWLConfig{JS_DIR} . '/' . $url
+            unless $url =~ m{^(?:(?:https?|ftp|file)://|/)};
+
+        next if grep {$_ eq $url} @{$self->{_required}{js}};
 
         $self->{_required}{js} = []
             unless $self->{_required}{js};
-        push @{$self->{_required}{js}} , $src;
+        push @{$self->{_required}{js}}, $url;
     }
 
     return $self;
 }
 
-=item B<requiredCSS> [B<URLS>]
+=item B<requiredCSS> (B<URLS>)
 
 Adds the list of urls (relative to CSS_DIR, or absolute) as required by the object
 
@@ -1015,18 +1014,109 @@ sub requiredCSS {
     my ($self, @urls) = @_;
 
     foreach my $url (@urls) {
-	my $src    = $url ;
-	$src       = $IWLConfig{SKIN_DIR} . '/' . $src
-	    unless $url =~ m{^(?:(?:https?|ftp|file)://|/)};
+        $url = $IWLConfig{SKIN_DIR} . '/' . $url
+            unless $url =~ m{^(?:(?:https?|ftp|file)://|/)};
+
+        next if grep {$_ eq $url} @{$self->{_required}{css}};
 
         $self->{_required}{css} = []
             unless $self->{_required}{css};
-        push @{$self->{_required}{css}} , $src;
+        push @{$self->{_required}{css}}, $url;
     }
 
     return $self;
 }
 
+=item B<require> (B<RESOURCES>)
+
+This method is a front-end to the L<IWL::Object::requiredJs|IWL::Object/requiredJs> and L<IWL::Object::requiredCSS|IWL::Object/requiredCSS> methods.
+It allows for setting of both I<CSS> and I<JavaScript> resources as required
+
+Parameters: B<RESOURCES> - a hash with the following recognised key-values:
+
+=over 8
+
+=item B<js>
+
+Expects a I<URL> or an array reference of I<URL>s for JavaScript files as a value
+
+=item B<css>
+
+Expects a I<URL> or an array reference of I<URL>s for CSS files as a value
+
+=back
+
+=cut
+
+sub require {
+    my ($self, %resources) = @_;
+    if (my $js = $resources{js}) {
+        $self->requiredJs('ARRAY' eq ref $js ? @$js : $js);
+    }
+    if (my $css = $resources{css}) {
+        $self->requiredCSS('ARRAY' eq ref $css ? @$css : $css);
+    }
+    return $self;
+}
+
+=item B<unrequire> (B<RESOURCES>)
+
+Un-requires the given resources for sharing. In case the resource is a javascript file or files, the later required files are also removed as requirements
+
+Parameters: B<RESOURCES> - See L<IWL::Object::require|IWL::Object/require> for parameter definition
+
+=cut
+
+sub unrequire {
+    my ($self, %resources) = @_;
+    if (my $js = $resources{js}) {
+        my @js = 'ARRAY' eq ref $js ? @$js : ($js);
+        my @required = @{$self->{_required}{js}};
+        foreach my $url (@js) {
+            $url = 'dist/prototype.js' if $url eq 'base.js';
+            $url = $IWLConfig{JS_DIR} . '/' . $url
+                unless $url =~ m{^(?:(?:https?|ftp|file)://|/)};
+            my ($index) = grep {$required[$_] eq $url} 0 .. $#required;
+            splice @{$self->{_required}{js}}, $index;
+        }
+    }
+    if (my $css = $resources{css}) {
+        foreach my $url ('ARRAY' eq ref $css ? @$css : ($css)) {
+            $url = $IWLConfig{SKIN_DIR} . '/' . $url
+                unless $url =~ m{^(?:(?:https?|ftp|file)://|/)};
+            $self->{_required}{css} = [grep { $_ ne $url } @{$self->{_required}{css}}];
+        }
+    }
+    return $self;
+}
+
+=item B<isRequired> (B<TYPE>, B<URL>)
+
+Returns true if the given resource are required by the object, or its parents
+
+Parameters: B<TYPE> - the type of resource. See L<IWL::Object::require|IWL::Object/require> for resource types, B<URL> - the B<URL> to check
+
+=cut
+
+sub isRequired {
+    my ($self, $type, $url) = @_;
+    my $top = $self->up(options => {last => 1}) || $self;
+    if ($type eq 'js') {
+        $url = $IWLConfig{JS_DIR} . '/' . $url
+            unless $url =~ m{^(?:(?:https?|ftp|file)://|/)};
+    } elsif ($type eq 'css') {
+        $url = $IWLConfig{SKIN_DIR} . '/' . $url
+            unless $url =~ m{^(?:(?:https?|ftp|file)://|/)};
+    }
+
+    return 1 if $top->{_shared}{$type}{$url};
+    foreach (@{$self->{_required}{$type} || []}) {
+        return 1 if $_ eq $url;
+    }
+
+    return;
+}
+
 =item B<cleanStateful>
 
 Class method that initializes all state data of the library.  Stateful
@@ -1185,7 +1275,7 @@ Searches upward along the object stack for objects, matching the criteria set by
 In scalar context, returns the first found object. In list context, returns all matching objects.
 Returns the parent object in scalar context, and parent objects in list context, if no criteria are given.
 
-See IWL::Object::match(3pm) for B<CRITERIA> documentation. If the method is invoked with the second syntax, B<CRITERIA> must be an array reference, instead of a list.
+See L<IWL::Object::match|/match> for B<CRITERIA> documentation. If the method is invoked with the second syntax, B<CRITERIA> must be an array reference, instead of a list.
 
 Parameters: B<OPTIONS> - a hash reference, with the following key-value pairs:
 
@@ -1235,7 +1325,7 @@ Searches downward along the object stack for objects, matching the criteria set
 In scalar context, returns the first found object. In list context, returns all matching objects.
 Returns the parent object in scalar context, and parent objects in list context, if no criteria are given.
 
-See IWL::Object::match(3pm) for B<CRITERIA> documentation. If the method is invoked with the second syntax, B<CRITERIA> must be an array reference, instead of a list.
+See L<IWL::Object::match|/match> for B<CRITERIA> documentation. If the method is invoked with the second syntax, B<CRITERIA> must be an array reference, instead of a list.
 
 Parameters: B<OPTIONS> - a hash reference, with the following key-value pairs:
 
@@ -1292,7 +1382,7 @@ Searches the next siblings of the object for objects, matching the criteria set
 In scalar context, returns the first found object. In list context, returns all matching objects.
 Returns the parent object in scalar context, and parent objects in list context, if no criteria are given.
 
-See IWL::Object::match(3pm) for B<CRITERIA> documentation. If the method is invoked with the second syntax, B<CRITERIA> must be an array reference, instead of a list.
+See L<IWL::Object::match|/match> for B<CRITERIA> documentation. If the method is invoked with the second syntax, B<CRITERIA> must be an array reference, instead of a list.
 
 Parameters: B<OPTIONS> - a hash reference, with the following key-value pairs:
 
@@ -1343,7 +1433,7 @@ Searches the previous siblings of the object for objects, matching the criteria
 In scalar context, returns the first found object. In list context, returns all matching objects.
 Returns the parent object in scalar context, and parent objects in list context, if no criteria are given.
 
-See IWL::Object::match(3pm) for B<CRITERIA> documentation. If the method is invoked with the second syntax, B<CRITERIA> must be an array reference, instead of a list.
+See L<IWL::Object::match|/match> for B<CRITERIA> documentation. If the method is invoked with the second syntax, B<CRITERIA> must be an array reference, instead of a list.
 
 Parameters: B<OPTIONS> - a hash reference, with the following key-value pairs:
 
@@ -1521,11 +1611,30 @@ Realizes the object. It is right before the object is serialized into HTML or JS
 
 sub _realize {
     my $self = shift;
+    my ($script, $head, $body, %required);
+
+    if ($self->{parentNode}) {
+        return $self unless %{$self->{_required}};
+        my $top = $self->up(options => {last => 1}) || $self;
+        my $env = $top->{environment} || {};
+        $self->{___top} = $top;
+
+        foreach my $resource (keys %{$self->{_required}}) {
+            foreach (@{$self->{_required}{$resource}}) {
+                next if $self->{_shared}{$resource}{$_} || $env->{_shared}{$resource}{$_};
+                $self->{_shared}{$resource}{$_} = $env->{_shared}{$resource}{$_} = 1;
+                push @{$required{$resource}}, $_;
+            }
+        }
+        $self->{_required} = {};
+
+        $self->__addRequired(%required) if %required;
+
+        return $self;
+    }
 
-    return if $self->{parentNode};
     my @descendants = ($self, $self->getDescendants);
     my $env = $self->{environment} || {};
-    my ($script, $head, $body, @scripts, %required);
 
     push @{$self->{_required}{$_}}, @{$env->{_required}{$_}}
         foreach keys %{$env->{_required}};
@@ -1545,11 +1654,9 @@ sub _realize {
                 push @{$required{$resource}}, $_;
             }
         }
-        delete $object->{_required};
+        $object->{_required} = {};
     }
     
-    require IWL::Script;
-
     my $pivot = $script
         ? $script->{parentNode}
             ? undef
@@ -1557,56 +1664,14 @@ sub _realize {
         : $body
             ? undef
             : $self->lastChild;
-    if (ref $required{js} eq 'ARRAY') {
-        if ($IWLConfig{STATIC_URI_SCRIPT} && $IWLConfig{STATIC_UNION}) {
-            my @required = @{$required{js}};
-            push @scripts,
-                IWL::Script->new->setAttribute('iwl:requiredScript')->setSrc(\@required) while @required;
-        } else {
-            @scripts = map {
-                IWL::Script->new->setAttribute('iwl:requiredScript')->setSrc($_)
-            } @{$required{js}};
-        }
+    $self->{___pivot}  = $pivot  and weaken $self->{___pivot};
+    $self->{___script} = $script and weaken $self->{___script};
+    $self->{___head}   = $head   and weaken $self->{___head};
+    $self->{___body}   = $body   and weaken $self->{___body};
 
-    }
+    $self->__addRequired(%required) if %required;
 
-    $self->{_lastShared} = $scripts[-1];
-
-    $script && $script->{parentNode}
-        ? $script->{parentNode}->insertBefore($script, @scripts)
-        : $pivot
-            ? $self->insertAfter($pivot, @scripts)
-            : ($body || $self)->appendChild(@scripts);
-
-    if (ref $required{css} eq 'ARRAY') {
-        if ($head) {
-            require IWL::Page::Link;
-            my @required = @{$required{css}};
-            my @css;
-
-            if ($IWLConfig{STATIC_URI_SCRIPT} && $IWLConfig{STATIC_UNION}) {
-                push @css,
-                    IWL::Page::Link->newLinkToCSS(\@required)->setAttribute('iwl:requiredCSS') while @required;
-            } else {
-                @css = map {IWL::Page::Link->newLinkToCSS($_)->setAttribute('iwl:requiredCSS')} @{$required{css}};
-            }
-            $head->appendChild(@css);
-        } else {
-            require IWL::Style;
-
-            my $style = IWL::Style->new->setAttribute('iwl:requiredCSS');
-            if ($IWLConfig{STATIC_URI_SCRIPT} && $IWLConfig{STATIC_UNION}) {
-                my @required = @{$required{css}};
-                $style->appendStyleImport(\@required) while @required;
-            } else {
-                $style->appendStyleImport($_) foreach @{$required{css}};
-            }
-
-            $self->isa('IWL::Page')
-                ? ($self->down({package => 'IWL::Page::Body'}) || $self)->prependChild($style)
-                : $self->prependChild($style);
-        }
-    }
+    return $self;
 }
 
 # Internal
@@ -1648,7 +1713,8 @@ sub __addInitScripts {
         my $expr = join '; ', @{$self->{_initScripts}};
         return unless $expr;
 
-        my $top = $self->up(options => {last => 1}) || $self;
+        my $top = $self->{___top} || $self->up(options => {last => 1}) || $self;
+        $self->{___top} = $top;
 
         unless ($top->{_initScript} && !$top->{_initScript}{_realized}) {
             require IWL::Script;
@@ -1656,18 +1722,19 @@ sub __addInitScripts {
             my $init = $top->{_initScript} = IWL::Script->new->setAttribute('iwl:initScript');
             weaken $top->{_initScript};
 
-            unless (($top->{_lastShared} && !$top->{_lastShared}{_realized}) || $top->{_firstScript}) {
+            unless (($top->{___lastShared} && !$top->{___lastShared}{_realized}) || $top->{___firstScript}) {
                 my $first = $top->down({package => 'IWL::Script'}, 'not', {attribute => ['iwl:requiredScript']});
-                $top->{_firstScript} = $first and weaken $top->{_firstScript};
+                $top->{___firstScript} = $first and weaken $top->{___firstScript};
             }
-            my $script = $top->{_firstScript};
+            my $script = $top->{___firstScript};
             undef $script if $script && $script->{_realized};
 
-            unless ($script || $top->{_pivot}) {
+            unless ($script || $top->{___pivot}) {
                 my $pivot = $top->lastChild;
-                $top->{_pivot} = $pivot and weaken $top->{_pivot};
+                $top->{___pivot} = $pivot and weaken $top->{___pivot};
             }
-            my $pivot = $top->{_lastShared} && !$top->{_lastShared}{_realized} ? $top->{_lastShared} : $top->{_pivot};
+            my $pivot = $top->{___lastShared} && !$top->{___lastShared}{_realized}
+                ? $top->{___lastShared} : $top->{___pivot};
             undef $pivot if $pivot && $pivot->{_realized};
 
             $script && $script->{parentNode}
@@ -1681,6 +1748,71 @@ sub __addInitScripts {
     }
 }
 
+sub __addRequired {
+    my ($self, %required) = @_;
+    my $top = $self->{___top} || $self;
+    my ($script, $pivot, $head, $body, @scripts) =
+        ($top->{___script}, $top->{___pivot}, $top->{___head}, $top->{___body});
+
+    if (ref $required{js} eq 'ARRAY') {
+        require IWL::Script;
+        if ($IWLConfig{STATIC_URI_SCRIPT} && $IWLConfig{STATIC_UNION}) {
+            my @required = @{$required{js}};
+            push @scripts,
+                IWL::Script->new->setAttribute('iwl:requiredScript')->setSrc(\@required) while @required;
+        } else {
+            @scripts = map {
+                IWL::Script->new->setAttribute('iwl:requiredScript')->setSrc($_)
+            } @{$required{js}};
+        }
+
+    }
+
+    $top->{___lastShared} = $scripts[-1];
+
+    if ($script && $script->{parentNode}) {
+        $script->{parentNode}->insertBefore($script, @scripts);
+    } elsif ($pivot && $pivot->{parentNode}) {
+        if ($self != $top) {
+            my $last = $pivot->next(options => {last => 1}, criteria => [{package => 'IWL::Script'}, {attribute => ['iwl:requiredScript']}]);
+            $pivot = $last if $last;
+        }
+        $pivot->{parentNode}->insertAfter($pivot, @scripts);
+    } else {
+        ($body || $self)->appendChild(@scripts);
+    }
+
+    if (ref $required{css} eq 'ARRAY') {
+        if ($head) {
+            require IWL::Page::Link;
+            my @required = @{$required{css}};
+            my @css;
+
+            if ($IWLConfig{STATIC_URI_SCRIPT} && $IWLConfig{STATIC_UNION}) {
+                push @css,
+                    IWL::Page::Link->newLinkToCSS(\@required)->setAttribute('iwl:requiredCSS') while @required;
+            } else {
+                @css = map {IWL::Page::Link->newLinkToCSS($_)->setAttribute('iwl:requiredCSS')} @{$required{css}};
+            }
+            $head->appendChild(@css);
+        } else {
+            require IWL::Style;
+
+            my $style = IWL::Style->new->setAttribute('iwl:requiredCSS');
+            if ($IWLConfig{STATIC_URI_SCRIPT} && $IWLConfig{STATIC_UNION}) {
+                my @required = @{$required{css}};
+                $style->appendStyleImport(\@required) while @required;
+            } else {
+                $style->appendStyleImport($_) foreach @{$required{css}};
+            }
+
+            $self->isa('IWL::Page')
+                ? ($self->down({package => 'IWL::Page::Body'}) || $self)->prependChild($style)
+                : $self->prependChild($style);
+        }
+    }
+}
+
 sub __addChildren {
     my ($self, @objects) = @_;
     return if $self->{_noChildren};
@@ -1689,7 +1821,6 @@ sub __addChildren {
     return unless @objects;
 
     my @children;
-    my $top = $self->up(options => {last => 1}) || $self;
     foreach my $object (grep {UNIVERSAL::isa($_, 'IWL::Object')} @objects) {
         $object->remove;
         $object->{parentNode} = $self and weaken $object->{parentNode};
@@ -1712,7 +1843,7 @@ $splitCriteria = sub {
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2006-2007  Viktor Kojouharov. All rights reserved.
+Copyright (c) 2006-2008  Viktor Kojouharov. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See perldoc perlartistic.
