@@ -13,7 +13,8 @@ use IWL::Entry;
 use IWL::Button;
 use IWL::JSON qw(toJSON);
 
-use Locale::TextDomain qw(org.bloka.iwl);
+use IWL::Config '%IWLConfig';
+use Locale::TextDomain $IWLConfig{TEXT_DOMAIN};
 
 =head1 NAME
 
@@ -183,7 +184,7 @@ sub _init {
     $self->{__pageCount} = $page_count;
     $self->{__pageEntry} = $page_entry;
 
-    $self->appendChild($first, $prev, $label, $next, $last);
+    $self->appendChild($first, $prev, $label, $next, $last, IWL::Container->new(class => 'iwl-clear'));
 
     $self->{__options} = {};
     $self->{__options}{pageCount} = $args{pageCount};
@@ -202,7 +203,7 @@ sub _init {
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2006-2007  Viktor Kojouharov. All rights reserved.
+Copyright (c) 2006-2008  Viktor Kojouharov. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See perldoc perlartistic.
