@@ -9,7 +9,7 @@ use base 'IWL::Table::Cell';
 
 use IWL::Config qw(%IWLConfig);
 use IWL::Image;
-use Locale::TextDomain qw(org.bloka.iwl);
+use Locale::TextDomain $IWLConfig{TEXT_DOMAIN};
 
 use constant IMAGES => {
     row_expand_T   => $IWLConfig{IMAGE_DIR} . '/tree/expander_t.gif',
@@ -175,7 +175,7 @@ sub _t_expand {
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2006-2007  Viktor Kojouharov. All rights reserved.
+Copyright (c) 2006-2008  Viktor Kojouharov. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See perldoc perlartistic.
