@@ -58,7 +58,11 @@ $rpc->handleEvent(
     sub {
         my ($params, $id, $elementData) = @_;
 
-        return {text => 'The combo was changed to ' . $elementData->{$id}}, $params;
+        if (int(rand(3))) {
+            return {text => 'The combo was changed to ' . $elementData->{$id}}, $params;
+        } else {
+            return {}, {error => 'rand returned 0'};
+        }
     },
 );
 
@@ -900,21 +904,26 @@ sub generate_notebook {
 sub generate_tooltips {
     my $container = IWL::Container->new(id => 'tooltips_container');
     my $button = IWL::Button->new(size => 'medium', style => {float => 'none', margin => '0 auto'});
-    my $label = IWL::Label->new(expand => 1, style => {'text-align' => 'center', border => '1px solid gray'});
+    my $label1 = IWL::Label->new(expand => 1, style => {'text-align' => 'center', border => '1px solid gray'});
     my $tip1 = IWL::Tooltip->new;
     my $tip2 = IWL::Tooltip->new(followMouse => 1);
+    my $tip3 = IWL::Tooltip->new(simple => 1);
     my $calendar = IWL::Calendar->new(id => 'calendar', showTime => 0, showWeekNumbers => 0, noMonthChange => 1);
+    my $label2 = $label1->clone->setId('simple_tooltip_label');
 
     $tip1->bindToWidget($button, 'click', 1);
     $tip1->setContent($calendar);
-    $tip2->bindToWidget($label, 'mouseover');
-    $tip2->bindHideToWidget($label, 'mouseout');
+    $tip2->bindToWidget($label1, 'mouseover');
+    $tip2->bindHideToWidget($label1, 'mouseout');
     $tip2->setContent('Some text here. Кирилица.');
+    $tip3->bindToWidget($label2, 'click', 1);
+    $tip3->setContent('More text.');
     $button->setLabel('Click for date');
-    $label->signalConnect(click => $tip1->showingCallback);
+    $label1->signalConnect(click => $tip1->showingCallback);
     $calendar->signalConnect(activate_date => $tip1->hidingCallback);
-    $label->setText('Hover over me');
-    $container->appendChild($button, $label, $tip1, $tip2);
+    $label1->setText('Hover over me');
+    $label2->setText('Click for a simpler tooltip');
+    $container->appendChild($button, $label1, $label2, $tip1, $tip2, $tip3);
 
     return $container;
 }
@@ -1019,11 +1028,12 @@ sub generate_rpc_events {
 	    insertion => 'bottom',
     });
     $button->registerEvent('IWL-Button-click', 'iwl_demo.pl', {}, {
-            onComplete => "IWL.Status.display(arguments[0].data.text)",
+            onComplete => "IWL.Status.display(json.data.text)",
             emitOnce => 1
     });
     $combo->registerEvent('IWL-Combo-change', 'iwl_demo.pl', {}, {
-            onComplete => "IWL.Status.display(arguments[0].data.text)",
+            onComplete => "IWL.Status.display(json.data.text)",
+            onError => "IWL.Status.display('A random error occurred: ' + json.extras.error)",
             collectData => 1
     });
 
@@ -1368,7 +1378,7 @@ sub show_the_code_for {
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2006-2007  Viktor Kojouharov. All rights reserved.
+Copyright (c) 2006-2008  Viktor Kojouharov. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See perldoc perlartistic.
