@@ -166,16 +166,15 @@ IWL.PageControl = Object.extend(Object.extend({}, IWL.Widget), (function () {
          * */
         getDimensions: function() {
             var dims = {width: 0, height: 0};
-            [this.firstButton, this.prevButton, this.nextButton, this.lastButton].concat(this.labelContainer.childElements()).each(
+            [this.firstButton, this.prevButton, this.nextButton, this.lastButton, this.labelContainer].each(
                 function(n) {
                     n = Element.extend(n);
-                    var d = n.getDimensions();
-                    var m = [n.getStyle('margin-top'), n.getStyle('margin-right'), n.getStyle('margin-bottom'), n.getStyle('margin-left')];
-                    dims.width += d.width + parseInt(m[1] || 0) + parseInt(m[3] || 0);
-
-                    dims.height = Math.max(d.height + parseInt(m[0] || 0) + parseInt(m[2] || 0), dims.height);
+                    var w = n.offsetWidth;
+                    var m = [n.getStyle('margin-left'), n.getStyle('margin-right')];
+                    dims.width += w + parseInt(m[0] || 0) + parseInt(m[1] || 0);
                 }.bind(this)
             );
+            dims.height = this.offsetHeight;
             /* 3px gap bug */
             if (Prototype.Browser.IE)
                 dims.width += 3 * this.labelContainer.select('span').length + 3;
@@ -185,7 +184,7 @@ IWL.PageControl = Object.extend(Object.extend({}, IWL.Widget), (function () {
             return dims;
         },
 
-        _init: function(id) {
+        _init: function() {
             var buttonCount = 5;
             var visibility = this.getStyle('visibility');
             this.style.visibility = 'hidden';
@@ -211,7 +210,7 @@ IWL.PageControl = Object.extend(Object.extend({}, IWL.Widget), (function () {
             this.options = Object.extend({
                 bound: false,
                 page: 1
-            }, arguments[1] || {});
+            }, arguments[0] || {});
             this.input.value = this.currentPage = this.options.page;
             this.show();
 
